
#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer dax__create_buffer
#define yy_delete_buffer dax__delete_buffer
#define yy_scan_buffer dax__scan_buffer
#define yy_scan_string dax__scan_string
#define yy_scan_bytes dax__scan_bytes
#define yy_init_buffer dax__init_buffer
#define yy_flush_buffer dax__flush_buffer
#define yy_load_buffer_state dax__load_buffer_state
#define yy_switch_to_buffer dax__switch_to_buffer
#define yypush_buffer_state dax_push_buffer_state
#define yypop_buffer_state dax_pop_buffer_state
#define yyensure_buffer_stack dax_ensure_buffer_stack
#define yy_flex_debug dax__flex_debug
#define yyin dax_in
#define yyleng dax_leng
#define yylex dax_lex
#define yylineno dax_lineno
#define yyout dax_out
#define yyrestart dax_restart
#define yytext dax_text
#define yywrap dax_wrap
#define yyalloc dax_alloc
#define yyrealloc dax_realloc
#define yyfree dax_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define dax__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer dax__create_buffer
#endif

#ifdef yy_delete_buffer
#define dax__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer dax__delete_buffer
#endif

#ifdef yy_scan_buffer
#define dax__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer dax__scan_buffer
#endif

#ifdef yy_scan_string
#define dax__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string dax__scan_string
#endif

#ifdef yy_scan_bytes
#define dax__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes dax__scan_bytes
#endif

#ifdef yy_init_buffer
#define dax__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer dax__init_buffer
#endif

#ifdef yy_flush_buffer
#define dax__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer dax__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define dax__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state dax__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define dax__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer dax__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define dax_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state dax_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define dax_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state dax_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define dax_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack dax_ensure_buffer_stack
#endif

#ifdef yylex
#define dax_lex_ALREADY_DEFINED
#else
#define yylex dax_lex
#endif

#ifdef yyrestart
#define dax_restart_ALREADY_DEFINED
#else
#define yyrestart dax_restart
#endif

#ifdef yylex_init
#define dax_lex_init_ALREADY_DEFINED
#else
#define yylex_init dax_lex_init
#endif

#ifdef yylex_init_extra
#define dax_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra dax_lex_init_extra
#endif

#ifdef yylex_destroy
#define dax_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy dax_lex_destroy
#endif

#ifdef yyget_debug
#define dax_get_debug_ALREADY_DEFINED
#else
#define yyget_debug dax_get_debug
#endif

#ifdef yyset_debug
#define dax_set_debug_ALREADY_DEFINED
#else
#define yyset_debug dax_set_debug
#endif

#ifdef yyget_extra
#define dax_get_extra_ALREADY_DEFINED
#else
#define yyget_extra dax_get_extra
#endif

#ifdef yyset_extra
#define dax_set_extra_ALREADY_DEFINED
#else
#define yyset_extra dax_set_extra
#endif

#ifdef yyget_in
#define dax_get_in_ALREADY_DEFINED
#else
#define yyget_in dax_get_in
#endif

#ifdef yyset_in
#define dax_set_in_ALREADY_DEFINED
#else
#define yyset_in dax_set_in
#endif

#ifdef yyget_out
#define dax_get_out_ALREADY_DEFINED
#else
#define yyget_out dax_get_out
#endif

#ifdef yyset_out
#define dax_set_out_ALREADY_DEFINED
#else
#define yyset_out dax_set_out
#endif

#ifdef yyget_leng
#define dax_get_leng_ALREADY_DEFINED
#else
#define yyget_leng dax_get_leng
#endif

#ifdef yyget_text
#define dax_get_text_ALREADY_DEFINED
#else
#define yyget_text dax_get_text
#endif

#ifdef yyget_lineno
#define dax_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno dax_get_lineno
#endif

#ifdef yyset_lineno
#define dax_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno dax_set_lineno
#endif

#ifdef yywrap
#define dax_wrap_ALREADY_DEFINED
#else
#define yywrap dax_wrap
#endif

#ifdef yyalloc
#define dax_alloc_ALREADY_DEFINED
#else
#define yyalloc dax_alloc
#endif

#ifdef yyrealloc
#define dax_realloc_ALREADY_DEFINED
#else
#define yyrealloc dax_realloc
#endif

#ifdef yyfree
#define dax_free_ALREADY_DEFINED
#else
#define yyfree dax_free
#endif

#ifdef yytext
#define dax_text_ALREADY_DEFINED
#else
#define yytext dax_text
#endif

#ifdef yyleng
#define dax_leng_ALREADY_DEFINED
#else
#define yyleng dax_leng
#endif

#ifdef yyin
#define dax_in_ALREADY_DEFINED
#else
#define yyin dax_in
#endif

#ifdef yyout
#define dax_out_ALREADY_DEFINED
#else
#define yyout dax_out
#endif

#ifdef yy_flex_debug
#define dax__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug dax__flex_debug
#endif

#ifdef yylineno
#define dax_lineno_ALREADY_DEFINED
#else
#define yylineno dax_lineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define dax_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 140
#define YY_END_OF_BUFFER 141
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
        static const flex_int16_t yy_accept[775] = {
            0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
            0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
            0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
            0,   0,   0,   0,   141, 139, 15,  10,  10,  15,  15,  119, 10,  119, 5,   6,   5,   8,   9,   8,   135,
            127, 128, 136, 133, 136, 134, 138, 127, 128, 138, 139, 40,  10,  40,  40,  40,  38,

            40,  40,  40,  40,  40,  40,  40,  44,  10,  44,  44,  139, 139, 44,  61,  10,  61,  61,  61,  59,  61,
            61,  61,  61,  61,  65,  10,  65,  139, 65,  92,  10,  92,  92,  92,  90,  92,  92,  92,  92,  92,  92,
            96,  10,  96,  103, 10,  103, 103, 103, 101, 103, 107, 10,  107, 139, 107, 114, 10,  114, 114, 114, 112,
            114, 118, 10,  118, 136, 135, 10,  0,   2,   2,   0,   4,   7,   130, 129, 0,   0,   0,   0,   0,   0,
            0,   39,  41,  41,  41,  41,  41,  41,  41,  41,  41,  41,  0,   0,   0,   0,

            0,   0,   0,   0,   60,  62,  62,  62,  62,  62,  62,  0,   0,   91,  93,  93,  93,  93,  93,  93,  93,
            93,  0,   102, 104, 104, 0,   0,   113, 115, 115, 0,   0,   0,   0,   0,   0,   0,   3,   0,   0,   0,
            0,   0,   0,   0,   137, 0,   41,  41,  41,  41,  41,  41,  41,  41,  41,  0,   0,   0,   0,   0,   0,
            0,   0,   0,   0,   0,   62,  62,  62,  62,  0,   0,   0,   93,  93,  93,  93,  93,  93,  93,  0,   0,
            104, 0,   0,   0,   115, 0,   0,   0,   132, 0,   14,  1,   0,   0,   125, 0,

            0,   0,   122, 121, 0,   0,   41,  41,  41,  41,  41,  41,  41,  41,  41,  0,   0,   43,  0,   0,   0,
            46,  0,   0,   45,  0,   0,   48,  47,  62,  62,  62,  62,  0,   0,   64,  0,   0,   93,  93,  93,  93,
            93,  93,  93,  0,   0,   95,  0,   0,   0,   0,   0,   106, 0,   0,   0,   0,   0,   0,   117, 0,   0,
            0,   0,   126, 120, 0,   0,   17,  41,  41,  41,  41,  41,  0,   0,   41,  41,  41,  0,   16,  0,   46,
            0,   66,  45,  0,   62,  0,   0,   62,  62,  62,  0,   67,  0,   0,   0,   0,

            93,  93,  0,   0,   93,  0,   0,   0,   0,   100, 99,  0,   0,   0,   111, 110, 0,   0,   0,   0,   0,
            12,  0,   123, 124, 17,  41,  0,   0,   41,  0,   0,   41,  0,   31,  30,  41,  0,   41,  0,   41,  0,
            16,  98,  0,   66,  97,  0,   0,   0,   52,  51,  62,  62,  62,  0,   63,  67,  0,   69,  68,  0,   0,
            0,   93,  93,  0,   89,  88,  93,  0,   87,  86,  0,   0,   0,   0,   0,   0,   0,   0,   11,  41,  0,
            27,  26,  41,  0,   29,  28,  41,  41,  41,  0,   19,  18,  41,  0,   42,  98,

            108, 97,  0,   58,  57,  62,  62,  62,  0,   0,   0,   0,   93,  93,  93,  0,   94,  0,   109, 0,   0,
            0,   0,   0,   41,  41,  41,  0,   0,   41,  41,  108, 62,  0,   0,   0,   0,   0,   0,   0,   0,   93,
            93,  93,  0,   105, 109, 0,   0,   0,   0,   0,   41,  41,  0,   0,   0,   25,  24,  41,  41,  62,  0,
            56,  55,  0,   54,  53,  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   116, 131, 0,   0,   0,
            41,  0,   0,   0,   33,  32,  0,   0,   41,  0,   0,   0,   0,   0,   0,   0,

            0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   35,  34,  0,   21,  20,  41,  0,
            50,  49,  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
            0,   37,  36,  41,  71,  0,   70,  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
            0,   0,   41,  73,  72,  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
            41,  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,

            0,   0,   0,   41,  0,   85,  0,   84,  0,   77,  0,   76,  0,   81,  0,   80,  0,   0,   0,   0,   0,
            0,   41,  83,  82,  75,  74,  79,  78,  0,   0,   0,   12,  0,   12,  0,   41,  0,   0,   0,   0,   0,
            41,  0,   0,   0,   0,   0,   11,  0,   23,  22,  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
            0,   0,   0,   0,   0,   0,   0,   0,   0,   13,  0};

        static const YY_CHAR yy_ec[256] = {
            0,  1,  1,  1,  1,  1,  1,  1,  1,  2,  3,  1,  2,  4,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
            1,  1,  1,  1,  1,  1,  2,  5,  6,  7,  1,  1,  8,  9,  1,  1,  1,  1,  1,  10, 11, 12, 13, 13, 13, 13,
            13, 13, 13, 13, 13, 13, 14, 15, 16, 17, 18, 19, 1,  20, 21, 22, 23, 24, 21, 25, 25, 25, 25, 25, 26, 27,
            25, 28, 29, 25, 25, 30, 31, 25, 25, 25, 25, 32, 25, 33, 1,  34, 1,  25, 1,  35, 36, 37, 38,

            39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 25, 57, 58, 59, 1,  1,  1,  1,
            1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
            1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
            1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,

            1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
            1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,  1,
            1,  1,  1};

        static const YY_CHAR yy_meta[60] = {0, 1, 2, 2, 2, 1, 1, 1, 1, 1, 3, 3, 1, 4, 5, 1, 1, 1, 6, 1,
                                            7, 7, 7, 7, 7, 5, 5, 5, 5, 5, 5, 5, 5, 1, 1, 7, 7, 7, 7, 7,
                                            7, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5};

        static const flex_int16_t yy_base[814] = {
            0,    0,    0,    0,    3,    6,    9,    24,   27,   11,   14,   15,   17,   29,   38,   45,   52,
            59,   61,   67,   70,   95,   0,    73,   76,   153,  156,  159,  162,  177,  180,  183,  186,  201,
            204,  207,  210,  226,  0,    284,  287,  290,  293,  308,  311,  314,  317,  333,  0,    391,  394,
            410,  462,  429,  432,  435,  438,  481,  484,  487,  490,  514,  566,  533,  536,  585,  587,  1886,
            2164, 2164, 397,  400,  47,   62,   2164, 453,  172,  2164, 2164, 1875, 2164, 2164, 1865, 2164, 1866,
            1863, 551,  2164, 2164, 2164, 2164, 1861, 1861, 1829, 441,  2164, 505,  1844, 0,    196,  2164,

            8,    1818, 1812, 1810, 1823, 1813, 35,   2164, 508,  593,  601,  589,  622,  630,  2164, 539,  1833,
            0,    303,  2164, 1811, 1809, 1793, 1772, 1786, 2164, 542,  649,  657,  676,  2164, 551,  1798, 0,
            442,  2164, 1772, 1770, 1750, 1760, 1751, 32,   2164, 557,  545,  2164, 607,  1775, 0,    494,  2164,
            1752, 2164, 612,  684,  703,  711,  2164, 667,  1764, 0,    546,  2164, 1722, 2164, 733,  641,  1752,
            1721, 739,  594,  1690, 2164, 1735, 1723, 2164, 2164, 2164, 2,    44,   1685, 1684, 1675, 1711, 1689,
            2164, 0,    1678, 1663, 1670, 1677, 1676, 1664, 1658, 1650, 1652, 1658, 1650, 1645, 1636,

            1645, 1626, 1628, 1630, 2164, 0,    747,  1615, 1618, 1615, 1610, 1616, 1599, 2164, 0,    1605, 1601,
            1590, 1602, 1582, 1601, 1585, 1578, 2164, 0,    1588, 1590, 1590, 2164, 0,    1584, 1572, 1584, 1594,
            1593, 1599, 431,  1554, 2164, 72,   0,    1549, 1549, 1581, 1576, 1541, 2164, 1553, 1540, 1535, 1533,
            1528, 1544, 1525, 1503, 1507, 1539, 765,  768,  1517, 1507, 1509, 1488, 1500, 1501, 1486, 771,  775,
            1489, 1487, 1467, 1467, 787,  790,  1479, 1477, 1470, 1470, 1459, 1462, 1445, 1429, 793,  796,  799,
            815,  818,  1415, 821,  824,  827,  1443, 2164, 1446, 2164, 2164, 17,   1400, 2164, 1428,

            1426, 1384, 2164, 2164, 1381, 1389, 1391, 1373, 1394, 1358, 1364, 844,  1368, 1357, 1344, 848,  851,
            2164, 854,  1355, 1344, 861,  1350, 1318, 871,  1324, 874,  2164, 2164, 1322, 882,  1317, 1316, 888,
            891,  2164, 894,  1301, 898,  901,  1304, 1295, 917,  1290, 920,  923,  929,  2164, 936,  940,  946,
            956,  959,  2164, 962,  1301, 965,  981,  968,  989,  2164, 992,  1309, 616,  995,  2164, 2164, 1316,
            1314, 998,  1302, 1013, 1274, 1016, 1266, 1019, 1022, 1269, 1035, 1279, 1038, 1043, 1274, 1051, 1253,
            1055, 1058, 1262, 1061, 1064, 1067, 1248, 1246, 1243, 1080, 1083, 1086, 1090, 1098, 1102,

            1242, 1231, 1110, 1114, 1244, 1122, 1126, 1134, 1138, 2164, 2164, 1146, 1234, 1151, 2164, 2164, 1159,
            1257, 632,  1258, 1163, 2164, 1256, 2164, 2164, 1166, 1224, 1169, 1176, 1216, 1172, 1191, 1212, 1201,
            2164, 2164, 1211, 1209, 1196, 1212, 1209, 1220, 1225, 1228, 1196, 1231, 1237, 1240, 1243, 1252, 2164,
            2164, 1213, 1198, 1188, 1260, 2164, 1263, 1266, 2164, 2164, 1277, 124,  125,  1190, 1181, 1285, 2164,
            2164, 1178, 1293, 2164, 2164, 1301, 1304, 1155, 1307, 1177, 578,  152,  5,    2164, 1151, 1311, 2164,
            2164, 1153, 1324, 2164, 2164, 1145, 1332, 1143, 1335, 2164, 2164, 1152, 1343, 2164, 1348,

            1354, 1360, 1363, 2164, 2164, 1153, 1371, 1374, 1140, 1129, 1135, 1104, 1112, 1104, 1099, 1377, 2164,
            1380, 1383, 1390, 1126, 174,  158,  280,  1097, 1089, 1397, 1400, 1403, 1091, 1086, 1416, 1092, 1419,
            1422, 1430, 1436, 1072, 1067, 1069, 1056, 1446, 1449, 1452, 1455, 2164, 1458, 1468, 1076, 1472, 176,
            510,  1053, 1475, 1478, 1485, 1494, 2164, 2164, 1502, 1062, 1505, 1508, 2164, 2164, 1521, 2164, 2164,
            1040, 1041, 1025, 1027, 1529, 1532, 1540, 1545, 1556, 1559, 1481, 2164, 2164, 1567, 287,  179,  1572,
            1575, 1578, 1591, 2164, 2164, 1601, 1604, 1049, 1612, 1617, 1020, 1017, 997,  995,  1628,

            633,  643,  1636, 651,  660,  1644, 670,  675,  412,  283,  538,  1652, 1655, 1664, 2164, 2164, 1672,
            2164, 2164, 999,  1680, 2164, 2164, 1037, 981,  1025, 978,  994,  975,  977,  959,  974,  956,  971,
            952,  968,  937,  953,  929,  605,  281,  434,  1688, 2164, 2164, 942,  2164, 972,  2164, 967,  927,
            901,  907,  896,  900,  890,  890,  874,  882,  859,  867,  856,  611,  614,  1696, 875,  2164, 2164,
            855,  820,  760,  773,  757,  770,  732,  713,  674,  686,  664,  670,  1699, 1702, 1705, 1722, 652,
            659,  673,  619,  616,  541,  556,  495,  496,  463,  495,  419,  444,  1730, 1733, 1740,

            1750, 1768, 1802, 381,  403,  2164, 399,  2164, 400,  2164, 396,  2164, 325,  2164, 319,  2164, 700,
            1820, 657,  613,  1838, 1872, 274,  2164, 2164, 2164, 2164, 2164, 2164, 660,  727,  200,  301,  745,
            295,  1760, 254,  726,  218,  202,  207,  1794, 1865, 480,  153,  1890, 1786, 738,  2164, 1828, 2164,
            2164, 1763, 1893, 664,  742,  741,  769,  814,  822,  823,  826,  744,  797,  789,  863,  849,  850,
            864,  898,  1906, 1910, 2164, 2164, 1928, 1935, 1942, 1949, 1956, 1963, 1970, 1977, 1984, 1991, 1998,
            2005, 2012, 2019, 2024, 2029, 2034, 2039, 2044, 2051, 2054, 2057, 2060, 2063, 2066, 2073,

            2077, 2083, 2089, 2095, 2101, 2107, 2114, 2121, 2128, 2135, 2142, 2149, 2156};

        static const flex_int16_t yy_def[814] = {
            0,   775, 775, 776, 776, 776, 776, 777, 777, 778, 778, 779, 779, 780, 780, 780, 780, 781, 781, 775, 775,
            774, 21,  782, 782, 782, 782, 775, 775, 782, 782, 775, 775, 782, 782, 782, 782, 774, 37,  783, 783, 775,
            775, 783, 783, 783, 783, 774, 47,  784, 784, 785, 785, 786, 786, 775, 775, 786, 786, 786, 786, 787, 787,
            788, 788, 780, 780, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,
            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 789, 774, 774,

            789, 789, 789, 789, 789, 789, 789, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 790, 774, 774, 790,
            790, 790, 790, 790, 774, 774, 774, 774, 774, 774, 774, 774, 791, 774, 774, 791, 791, 791, 791, 791, 791,
            774, 774, 774, 774, 774, 774, 792, 774, 774, 792, 774, 774, 774, 774, 774, 774, 774, 774, 793, 774, 774,
            793, 774, 774, 774, 774, 774, 774, 794, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,
            774, 774, 789, 789, 789, 789, 789, 789, 789, 789, 789, 789, 795, 774, 774, 774,

            774, 774, 774, 774, 774, 790, 790, 790, 790, 790, 790, 796, 774, 774, 791, 791, 791, 791, 791, 791, 791,
            791, 797, 774, 792, 792, 798, 774, 774, 793, 793, 799, 774, 774, 800, 774, 800, 774, 774, 774, 801, 774,
            774, 774, 774, 774, 774, 774, 789, 789, 789, 789, 789, 789, 789, 789, 789, 802, 802, 774, 774, 774, 774,
            774, 774, 774, 774, 774, 790, 790, 790, 790, 803, 803, 774, 791, 791, 791, 791, 791, 791, 791, 804, 804,
            792, 805, 805, 774, 793, 806, 806, 774, 774, 800, 774, 774, 800, 774, 774, 801,

            774, 774, 774, 774, 774, 774, 789, 789, 789, 789, 789, 789, 789, 789, 789, 774, 802, 774, 802, 774, 774,
            774, 774, 774, 774, 774, 774, 774, 774, 790, 790, 790, 790, 774, 803, 774, 803, 774, 791, 791, 791, 791,
            791, 791, 791, 774, 804, 774, 804, 774, 774, 774, 805, 774, 805, 774, 774, 774, 774, 806, 774, 806, 774,
            800, 807, 774, 774, 774, 774, 774, 789, 789, 789, 789, 789, 774, 774, 789, 789, 789, 802, 774, 774, 774,
            774, 774, 774, 774, 790, 774, 774, 790, 790, 790, 803, 774, 774, 774, 774, 774,

            791, 791, 774, 774, 791, 774, 774, 804, 774, 774, 774, 805, 774, 774, 774, 774, 806, 774, 800, 807, 807,
            774, 807, 774, 774, 774, 789, 774, 774, 789, 774, 774, 789, 774, 774, 774, 789, 774, 789, 774, 789, 802,
            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 790, 790, 790, 774, 774, 774, 774, 774, 774, 774, 774,
            774, 791, 791, 774, 774, 774, 791, 774, 774, 774, 804, 805, 774, 806, 774, 800, 807, 807, 774, 789, 774,
            774, 774, 789, 774, 774, 774, 789, 789, 789, 774, 774, 774, 789, 774, 774, 774,

            774, 774, 774, 774, 774, 790, 790, 790, 774, 774, 774, 774, 791, 791, 791, 774, 774, 805, 774, 806, 774,
            800, 807, 807, 789, 789, 789, 774, 774, 789, 789, 774, 790, 774, 774, 774, 774, 774, 774, 774, 774, 791,
            791, 791, 774, 774, 774, 806, 774, 800, 807, 807, 789, 789, 774, 774, 774, 774, 774, 789, 789, 790, 774,
            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 800, 807, 807,
            789, 774, 774, 774, 774, 774, 774, 774, 789, 774, 774, 774, 774, 774, 774, 774,

            774, 774, 774, 774, 774, 774, 774, 774, 800, 807, 807, 774, 774, 774, 774, 774, 774, 774, 774, 789, 774,
            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 800, 807, 807,
            774, 774, 774, 789, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 800,
            807, 807, 789, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 800, 807, 807, 807,
            789, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 800, 807, 807,

            807, 808, 809, 789, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 800, 807, 810, 811, 808,
            809, 789, 774, 774, 774, 774, 774, 774, 800, 810, 807, 812, 811, 813, 807, 789, 800, 812, 774, 813, 807,
            789, 800, 774, 774, 774, 800, 774, 774, 774, 774, 800, 800, 800, 800, 800, 800, 800, 800, 800, 800, 800,
            800, 800, 800, 800, 800, 800, 800, 800, 800, 774, 0,   774, 774, 774, 774, 774, 774, 774, 774, 774, 774,
            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,

            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774};

        static const flex_int16_t yy_nxt[2224] = {
            0,   774, 70,  71,  70,  70,  71,  70,  70,  71,  70,  70,  71,  70,  78,  240, 72,  78,  81,  72,  81,
            79,  73,  422, 79,  73,  75,  71,  75,  75,  71,  75,  84,  85,  82,  295, 82,  86,  87,  364, 76,  84,
            85,  76,  524, 88,  86,  87,  84,  85,  188, 89,  171, 86,  88,  84,  85,  189, 89,  241, 86,  88,  91,
            92,  91,  92,  172, 171, 88,  71,  71,  71,  71,  71,  71,  109, 71,  109, 109, 71,  109, 173, 195, 94,
            221, 240, 94,  299, 196, 110, 222, 242, 110, 93,  243, 93,  95,  96,  71,  96,  95,

            95,  95,  95,  95,  95,  95,  97,  95,  98,  95,  99,  95,  100, 95,  98,  98,  98,  98,  98,  98,  98,
            98,  98,  98,  98,  98,  98,  95,  95,  98,  98,  101, 98,  98,  102, 98,  98,  103, 104, 98,  98,  98,
            105, 98,  98,  98,  98,  98,  98,  98,  106, 107, 98,  98,  109, 71,  109, 109, 71,  109, 71,  71,  71,
            71,  71,  71,  509, 511, 111, 422, 749, 111, 510, 512, 112, 422, 174, 112, 109, 71,  109, 109, 71,  109,
            71,  71,  71,  71,  71,  71,  173, 295, 110, 422, 551, 110, 422, 550, 113, 523,

            174, 113, 109, 71,  109, 109, 71,  109, 109, 71,  109, 109, 71,  109, 173, 740, 111, 422, 423, 111, 745,
            611, 114, 740, 583, 114, 115, 116, 71,  116, 115, 115, 115, 115, 115, 115, 115, 117, 115, 118, 115, 119,
            115, 120, 115, 118, 118, 118, 118, 118, 118, 118, 118, 118, 118, 118, 118, 118, 115, 115, 118, 118, 118,
            118, 118, 118, 118, 118, 121, 118, 118, 122, 118, 123, 118, 118, 118, 124, 118, 118, 118, 125, 118, 118,
            118, 127, 71,  127, 127, 71,  127, 71,  71,  71,  71,  71,  71,  422, 422, 128,

            422, 743, 128, 740, 422, 129, 740, 174, 129, 127, 71,  127, 127, 71,  127, 127, 71,  127, 127, 71,  127,
            173, 737, 128, 610, 641, 128, 729, 664, 130, 728, 552, 130, 131, 132, 71,  132, 131, 131, 131, 131, 131,
            131, 131, 133, 131, 134, 131, 135, 131, 136, 131, 134, 134, 134, 134, 134, 134, 134, 134, 134, 134, 134,
            134, 134, 131, 131, 134, 134, 134, 134, 134, 137, 134, 134, 134, 134, 134, 138, 134, 134, 139, 134, 134,
            140, 141, 142, 134, 134, 134, 134, 134, 144, 71,  144, 144, 71,  144, 170, 170,

            170, 170, 170, 170, 727, 726, 145, 725, 724, 145, 146, 147, 71,  147, 146, 146, 146, 146, 146, 146, 146,
            148, 146, 723, 146, 150, 146, 151, 146, 295, 154, 71,  154, 154, 71,  154, 71,  71,  71,  71,  71,  71,
            146, 146, 155, 174, 174, 155, 295, 640, 156, 422, 716, 156, 170, 170, 170, 715, 297, 173, 173, 152, 146,
            147, 71,  147, 146, 146, 146, 146, 146, 146, 146, 148, 146, 185, 146, 150, 146, 151, 146, 665, 154, 71,
            154, 154, 71,  154, 154, 71,  154, 154, 71,  154, 146, 146, 155, 295, 174, 155,

            714, 713, 157, 748, 712, 157, 170, 170, 170, 170, 170, 170, 173, 152, 158, 159, 71,  159, 158, 158, 158,
            158, 158, 158, 158, 160, 158, 422, 158, 162, 158, 163, 158, 711, 166, 71,  166, 166, 71,  166, 170, 170,
            170, 170, 170, 170, 158, 158, 167, 174, 174, 167, 170, 170, 170, 422, 223, 179, 170, 170, 170, 710, 584,
            173, 173, 164, 158, 159, 71,  159, 158, 158, 158, 158, 158, 158, 158, 160, 158, 709, 158, 162, 158, 163,
            158, 180, 642, 84,  85,  84,  85,  181, 86,  174, 86,  295, 182, 174, 158, 158,

            168, 183, 168, 236, 197, 174, 522, 173, 170, 170, 170, 173, 197, 170, 170, 170, 237, 164, 169, 173, 169,
            732, 295, 198, 708, 204, 174, 198, 295, 199, 735, 422, 200, 295, 174, 198, 200, 199, 201, 663, 173, 197,
            201, 202, 203, 174, 419, 202, 173, 295, 201, 681, 232, 174, 682, 202, 198, 707, 199, 173, 212, 174, 732,
            479, 198, 203, 204, 173, 170, 170, 170, 201, 628, 203, 733, 173, 202, 295, 706, 201, 174, 295, 630, 198,
            202, 204, 629, 212, 174, 738, 632, 198, 203, 204, 173, 227, 631, 705, 201, 634,

            203, 757, 173, 213, 633, 704, 201, 174, 697, 636, 198, 213, 204, 635, 638, 174, 696, 295, 198, 203, 204,
            173, 227, 637, 695, 201, 694, 203, 639, 173, 202, 730, 732, 228, 170, 170, 170, 198, 202, 204, 170, 170,
            170, 295, 733, 198, 203, 204, 267, 267, 267, 693, 228, 732, 203, 295, 744, 202, 295, 295, 201, 295, 735,
            268, 753, 202, 316, 316, 316, 316, 316, 316, 267, 267, 267, 759, 327, 327, 327, 758, 328, 765, 318, 329,
            692, 318, 295, 268, 334, 334, 334, 334, 334, 334, 346, 346, 346, 346, 346, 346,

            350, 350, 350, 760, 336, 319, 295, 336, 691, 690, 348, 689, 688, 348, 295, 351, 352, 352, 352, 352, 352,
            352, 357, 357, 357, 359, 359, 359, 359, 359, 359, 295, 354, 763, 766, 354, 764, 358, 337, 295, 295, 361,
            767, 295, 361, 376, 376, 376, 349, 316, 316, 316, 316, 316, 316, 316, 316, 316, 687, 355, 377, 362, 384,
            384, 384, 318, 295, 295, 318, 771, 761, 318, 387, 387, 387, 327, 327, 327, 762, 328, 295, 295, 329, 390,
            390, 390, 769, 770, 381, 334, 334, 334, 334, 334, 334, 334, 334, 334, 391, 397,

            397, 397, 399, 399, 399, 336, 771, 686, 336, 685, 680, 336, 679, 678, 398, 295, 768, 400, 403, 403, 403,
            406, 406, 406, 346, 346, 346, 677, 676, 395, 346, 346, 346, 404, 392, 675, 407, 346, 346, 346, 348, 350,
            350, 350, 674, 673, 348, 409, 409, 409, 672, 410, 671, 348, 411, 670, 351, 352, 352, 352, 352, 352, 352,
            352, 352, 352, 357, 357, 357, 359, 359, 359, 669, 354, 408, 668, 354, 667, 666, 354, 662, 358, 414, 414,
            414, 361, 415, 661, 660, 416, 359, 359, 359, 359, 359, 359, 421, 421, 421, 426,

            426, 426, 659, 658, 412, 657, 361, 656, 655, 361, 654, 653, 422, 423, 428, 428, 428, 431, 431, 431, 376,
            376, 376, 434, 434, 434, 652, 435, 651, 429, 436, 650, 432, 649, 648, 377, 438, 438, 438, 316, 316, 316,
            647, 417, 443, 443, 443, 646, 439, 627, 626, 440, 384, 384, 384, 318, 446, 446, 446, 387, 387, 387, 448,
            448, 448, 390, 390, 390, 450, 450, 450, 625, 451, 624, 620, 452, 599, 449, 442, 598, 391, 456, 456, 456,
            458, 458, 458, 397, 397, 397, 597, 459, 459, 459, 596, 460, 593, 457, 461, 399,

            399, 399, 398, 462, 462, 462, 585, 463, 581, 572, 464, 403, 403, 403, 400, 467, 467, 467, 571, 468, 570,
            569, 469, 406, 406, 406, 404, 471, 471, 471, 562, 472, 561, 560, 473, 346, 346, 346, 407, 409, 409, 409,
            554, 410, 553, 549, 411, 352, 352, 352, 544, 348, 414, 414, 414, 543, 415, 542, 541, 416, 359, 359, 359,
            354, 421, 421, 421, 426, 426, 426, 428, 428, 428, 431, 431, 431, 361, 484, 484, 484, 422, 485, 540, 539,
            486, 429, 474, 538, 432, 533, 531, 475, 488, 488, 488, 530, 489, 477, 527, 490,

            526, 480, 434, 434, 434, 525, 435, 521, 519, 436, 438, 438, 438, 494, 494, 494, 515, 495, 481, 514, 496,
            498, 498, 498, 513, 440, 443, 443, 443, 500, 500, 500, 446, 446, 446, 508, 507, 499, 502, 502, 502, 448,
            448, 448, 503, 503, 503, 506, 504, 501, 497, 505, 493, 450, 450, 450, 449, 451, 492, 491, 452, 456, 456,
            456, 458, 458, 458, 459, 459, 459, 487, 460, 483, 482, 461, 422, 478, 457, 462, 462, 462, 476, 463, 470,
            466, 464, 467, 467, 467, 465, 468, 455, 454, 469, 471, 471, 471, 453, 472, 447,

            445, 473, 516, 516, 516, 352, 352, 352, 359, 359, 359, 444, 484, 484, 484, 441, 485, 437, 517, 486, 433,
            354, 430, 427, 361, 488, 488, 488, 425, 489, 424, 418, 490, 528, 528, 528, 494, 494, 494, 413, 495, 518,
            405, 496, 498, 498, 498, 402, 529, 500, 500, 500, 401, 396, 520, 532, 532, 532, 394, 393, 499, 502, 502,
            502, 503, 503, 503, 389, 504, 388, 386, 505, 534, 534, 534, 536, 536, 536, 516, 516, 516, 545, 545, 545,
            547, 547, 547, 535, 385, 383, 537, 359, 359, 359, 517, 382, 380, 546, 555, 555,

            555, 528, 528, 528, 557, 557, 557, 361, 558, 379, 378, 559, 375, 556, 374, 373, 529, 532, 532, 532, 534,
            534, 534, 563, 563, 563, 372, 564, 371, 370, 565, 536, 536, 536, 369, 535, 368, 566, 566, 566, 367, 567,
            366, 548, 568, 365, 537, 573, 573, 573, 575, 575, 575, 577, 577, 577, 545, 545, 545, 547, 547, 547, 574,
            295, 363, 576, 356, 345, 578, 579, 579, 579, 546, 582, 582, 582, 586, 586, 586, 555, 555, 555, 579, 579,
            579, 580, 588, 588, 588, 295, 589, 587, 344, 590, 556, 557, 557, 557, 580, 558,

            343, 342, 559, 591, 591, 591, 594, 594, 594, 563, 563, 563, 341, 564, 340, 339, 565, 338, 592, 333, 332,
            595, 566, 566, 566, 331, 567, 330, 326, 568, 573, 573, 573, 600, 600, 600, 325, 601, 324, 323, 602, 575,
            575, 575, 322, 574, 603, 603, 603, 321, 604, 320, 315, 605, 314, 313, 576, 577, 577, 577, 606, 606, 606,
            312, 607, 311, 310, 608, 582, 582, 582, 309, 578, 612, 612, 612, 586, 586, 586, 614, 614, 614, 308, 615,
            295, 307, 616, 306, 613, 305, 304, 587, 588, 588, 588, 303, 589, 302, 301, 590,

            298, 609, 591, 591, 591, 617, 617, 617, 296, 618, 295, 293, 619, 594, 594, 594, 292, 592, 621, 621, 621,
            291, 622, 289, 288, 623, 287, 285, 595, 600, 600, 600, 284, 601, 282, 281, 602, 603, 603, 603, 280, 604,
            279, 278, 605, 606, 606, 606, 277, 607, 276, 275, 608, 612, 612, 612, 643, 643, 643, 274, 644, 272, 271,
            645, 270, 614, 614, 614, 613, 615, 269, 266, 616, 617, 617, 617, 265, 618, 264, 263, 619, 621, 621, 621,
            262, 622, 261, 260, 623, 643, 643, 643, 259, 644, 257, 256, 645, 683, 683, 683,

            698, 698, 698, 699, 699, 699, 683, 683, 683, 255, 254, 253, 684, 422, 252, 251, 295, 250, 700, 422, 249,
            684, 422, 701, 701, 701, 248, 702, 247, 246, 703, 698, 698, 698, 699, 699, 699, 245, 244, 422, 239, 718,
            718, 718, 236, 719, 238, 295, 720, 700, 422, 701, 701, 701, 234, 702, 233, 422, 703, 717, 231, 742, 742,
            742, 754, 754, 754, 422, 420, 420, 420, 420, 420, 420, 420, 420, 420, 422, 423, 420, 295, 229, 420, 420,
            420, 422, 420, 750, 750, 750, 226, 751, 224, 220, 752, 742, 742, 742, 219, 218,

            420, 420, 420, 420, 420, 420, 420, 420, 420, 420, 420, 422, 217, 420, 216, 214, 420, 420, 420, 422, 420,
            718, 718, 718, 211, 719, 210, 209, 720, 750, 750, 750, 480, 751, 420, 420, 752, 422, 420, 420, 420, 420,
            420, 736, 420, 420, 420, 208, 207, 420, 205, 194, 420, 420, 420, 422, 420, 193, 192, 191, 190, 186, 184,
            178, 177, 178, 746, 746, 746, 177, 420, 420, 420, 420, 420, 420, 420, 420, 420, 420, 736, 747, 176, 420,
            175, 774, 420, 420, 420, 422, 420, 746, 746, 746, 754, 754, 754, 774, 755, 774,

            774, 756, 774, 774, 420, 420, 747, 772, 772, 772, 295, 772, 772, 772, 774, 774, 774, 774, 774, 774, 774,
            774, 774, 773, 774, 774, 774, 773, 68,  68,  68,  68,  68,  68,  68,  69,  69,  69,  69,  69,  69,  69,
            74,  74,  74,  74,  74,  74,  74,  77,  77,  77,  77,  77,  77,  77,  80,  80,  80,  80,  80,  80,  80,
            83,  83,  83,  83,  83,  83,  83,  90,  90,  90,  90,  90,  90,  90,  108, 108, 108, 108, 108, 108, 108,
            126, 126, 126, 126, 126, 126, 126, 143, 143, 143, 143, 143, 143, 143, 149, 149,

            149, 149, 149, 149, 149, 153, 153, 153, 153, 153, 153, 153, 161, 161, 161, 161, 161, 161, 161, 165, 165,
            165, 165, 165, 165, 165, 187, 187, 187, 774, 187, 206, 206, 206, 774, 206, 215, 215, 215, 774, 215, 225,
            225, 225, 774, 225, 230, 230, 230, 774, 230, 235, 235, 235, 235, 235, 774, 235, 258, 774, 258, 273, 774,
            273, 283, 774, 283, 286, 774, 286, 290, 774, 290, 294, 294, 294, 294, 294, 294, 294, 300, 774, 774, 300,
            317, 317, 317, 317, 317, 317, 335, 335, 335, 335, 335, 335, 347, 347, 347, 347,

            347, 347, 353, 353, 353, 353, 353, 353, 360, 360, 360, 360, 360, 360, 420, 420, 420, 420, 420, 420, 420,
            721, 721, 721, 721, 721, 721, 721, 722, 722, 722, 722, 722, 722, 722, 731, 731, 731, 731, 731, 731, 731,
            734, 734, 734, 734, 734, 734, 734, 739, 739, 739, 739, 739, 739, 739, 741, 741, 741, 741, 741, 741, 741,
            67,  774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,
            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,

            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,
            774, 774};

        static const flex_int16_t yy_chk[2224] = {
            0,   0,   3,   3,   3,   4,   4,   4,   5,   5,   5,   6,   6,   6,   9,   179, 3,   10,  11,  4,   12,
            9,   5,   481, 10,  6,   7,   7,   7,   8,   8,   8,   13,  13,  11,  297, 12,  13,  13,  297, 7,   14,
            14,  8,   481, 13,  14,  14,  15,  15,  101, 15,  72,  15,  14,  16,  16,  101, 16,  179, 16,  15,  17,
            17,  18,  18,  72,  73,  16,  19,  19,  19,  20,  20,  20,  23,  23,  23,  24,  24,  24,  73,  107, 19,
            142, 240, 20,  240, 107, 23,  142, 180, 24,  17,  180, 18,  21,  21,  21,  21,  21,

            21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,
            21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,
            21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  21,  25,  25,  25,  26,  26,  26,  27,  27,  27,
            28,  28,  28,  463, 464, 25,  480, 745, 26,  463, 464, 27,  523, 76,  28,  29,  29,  29,  30,  30,  30,
            31,  31,  31,  32,  32,  32,  76,  522, 29,  551, 523, 30,  584, 522, 31,  480,

            99,  32,  33,  33,  33,  34,  34,  34,  35,  35,  35,  36,  36,  36,  99,  741, 33,  732, 732, 34,  740,
            584, 35,  739, 551, 36,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,
            37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,
            37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,  37,
            37,  39,  39,  39,  40,  40,  40,  41,  41,  41,  42,  42,  42,  524, 641, 39,

            610, 737, 40,  735, 583, 41,  733, 119, 42,  43,  43,  43,  44,  44,  44,  45,  45,  45,  46,  46,  46,
            119, 723, 43,  583, 610, 44,  715, 641, 45,  713, 524, 46,  47,  47,  47,  47,  47,  47,  47,  47,  47,
            47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,
            47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,  47,
            47,  47,  47,  47,  47,  47,  47,  47,  49,  49,  49,  50,  50,  50,  70,  70,

            70,  71,  71,  71,  711, 709, 49,  707, 705, 50,  51,  51,  51,  51,  51,  51,  51,  51,  51,  51,  51,
            51,  51,  704, 51,  51,  51,  51,  51,  609, 53,  53,  53,  54,  54,  54,  55,  55,  55,  56,  56,  56,
            51,  51,  53,  94,  135, 54,  237, 609, 55,  642, 697, 56,  75,  75,  75,  696, 237, 94,  135, 51,  52,
            52,  52,  52,  52,  52,  52,  52,  52,  52,  52,  52,  52,  94,  52,  52,  52,  52,  52,  642, 57,  57,
            57,  58,  58,  58,  59,  59,  59,  60,  60,  60,  52,  52,  57,  744, 150, 58,

            695, 694, 59,  744, 693, 60,  96,  96,  96,  109, 109, 109, 150, 52,  61,  61,  61,  61,  61,  61,  61,
            61,  61,  61,  61,  61,  61,  552, 61,  61,  61,  61,  61,  692, 63,  63,  63,  64,  64,  64,  116, 116,
            116, 127, 127, 127, 61,  61,  63,  145, 162, 64,  132, 132, 132, 611, 145, 86,  144, 144, 144, 691, 552,
            145, 162, 61,  62,  62,  62,  62,  62,  62,  62,  62,  62,  62,  62,  62,  62,  690, 62,  62,  62,  62,
            62,  86,  611, 65,  65,  66,  66,  86,  65,  112, 66,  479, 86,  110, 62,  62,

            65,  86,  66,  171, 110, 111, 479, 112, 147, 147, 147, 110, 111, 154, 154, 154, 171, 62,  65,  111, 66,
            720, 640, 112, 689, 112, 113, 110, 663, 110, 720, 664, 112, 364, 114, 111, 110, 111, 112, 640, 113, 114,
            110, 112, 111, 167, 364, 110, 114, 419, 111, 663, 167, 128, 664, 111, 113, 688, 113, 167, 128, 129, 719,
            419, 114, 113, 114, 128, 159, 159, 159, 113, 601, 114, 719, 129, 113, 730, 687, 114, 130, 755, 602, 128,
            114, 128, 601, 130, 155, 730, 604, 129, 128, 129, 130, 155, 602, 686, 128, 605,

            129, 755, 155, 128, 604, 685, 129, 156, 680, 607, 130, 129, 130, 605, 608, 157, 679, 717, 155, 130, 155,
            156, 157, 607, 678, 130, 677, 155, 608, 157, 130, 717, 731, 155, 166, 166, 166, 156, 155, 156, 170, 170,
            170, 738, 731, 157, 156, 157, 207, 207, 207, 676, 156, 734, 157, 748, 738, 156, 757, 756, 157, 763, 734,
            207, 748, 157, 258, 258, 258, 259, 259, 259, 267, 267, 267, 757, 268, 268, 268, 756, 268, 763, 258, 268,
            675, 259, 758, 267, 273, 273, 273, 274, 274, 274, 283, 283, 283, 284, 284, 284,

            285, 285, 285, 758, 273, 259, 765, 274, 674, 673, 283, 672, 671, 284, 764, 285, 286, 286, 286, 287, 287,
            287, 289, 289, 289, 290, 290, 290, 291, 291, 291, 759, 286, 761, 764, 287, 762, 289, 274, 760, 761, 290,
            765, 762, 291, 312, 312, 312, 284, 316, 316, 316, 317, 317, 317, 319, 319, 319, 670, 287, 312, 291, 322,
            322, 322, 316, 767, 768, 317, 769, 759, 319, 325, 325, 325, 327, 327, 327, 760, 327, 766, 769, 327, 331,
            331, 331, 767, 768, 319, 334, 334, 334, 335, 335, 335, 337, 337, 337, 331, 339,

            339, 339, 340, 340, 340, 334, 770, 669, 335, 666, 662, 337, 661, 660, 339, 770, 766, 340, 343, 343, 343,
            345, 345, 345, 346, 346, 346, 659, 658, 337, 347, 347, 347, 343, 331, 657, 345, 349, 349, 349, 346, 350,
            350, 350, 656, 655, 347, 351, 351, 351, 654, 351, 653, 349, 351, 652, 350, 352, 352, 352, 353, 353, 353,
            355, 355, 355, 357, 357, 357, 359, 359, 359, 651, 352, 349, 650, 353, 648, 646, 355, 639, 357, 358, 358,
            358, 359, 358, 638, 637, 358, 360, 360, 360, 362, 362, 362, 365, 365, 365, 370,

            370, 370, 636, 635, 355, 634, 360, 633, 632, 362, 631, 630, 365, 365, 372, 372, 372, 374, 374, 374, 376,
            376, 376, 377, 377, 377, 629, 377, 628, 372, 377, 627, 374, 626, 625, 376, 379, 379, 379, 381, 381, 381,
            624, 362, 382, 382, 382, 620, 379, 599, 598, 379, 384, 384, 384, 381, 386, 386, 386, 387, 387, 387, 389,
            389, 389, 390, 390, 390, 391, 391, 391, 597, 391, 596, 593, 391, 572, 389, 381, 571, 390, 395, 395, 395,
            396, 396, 396, 397, 397, 397, 570, 398, 398, 398, 569, 398, 561, 395, 398, 399,

            399, 399, 397, 400, 400, 400, 553, 400, 549, 541, 400, 403, 403, 403, 399, 404, 404, 404, 540, 404, 539,
            538, 404, 406, 406, 406, 403, 407, 407, 407, 533, 407, 531, 530, 407, 408, 408, 408, 406, 409, 409, 409,
            526, 409, 525, 521, 409, 412, 412, 412, 515, 408, 414, 414, 414, 514, 414, 513, 512, 414, 417, 417, 417,
            412, 421, 421, 421, 426, 426, 426, 428, 428, 428, 431, 431, 431, 417, 429, 429, 429, 421, 429, 511, 510,
            429, 428, 408, 509, 431, 506, 497, 412, 432, 432, 432, 493, 432, 417, 491, 432,

            487, 421, 434, 434, 434, 483, 434, 478, 476, 434, 438, 438, 438, 440, 440, 440, 470, 440, 421, 466, 440,
            442, 442, 442, 465, 438, 443, 443, 443, 444, 444, 444, 446, 446, 446, 455, 454, 442, 447, 447, 447, 448,
            448, 448, 449, 449, 449, 453, 449, 445, 441, 449, 439, 450, 450, 450, 448, 450, 437, 433, 450, 456, 456,
            456, 458, 458, 458, 459, 459, 459, 430, 459, 427, 423, 459, 420, 418, 456, 462, 462, 462, 413, 462, 405,
            402, 462, 467, 467, 467, 401, 467, 394, 393, 467, 471, 471, 471, 392, 471, 388,

            385, 471, 474, 474, 474, 475, 475, 475, 477, 477, 477, 383, 484, 484, 484, 380, 484, 378, 474, 484, 375,
            475, 373, 371, 477, 488, 488, 488, 369, 488, 368, 363, 488, 492, 492, 492, 494, 494, 494, 356, 494, 475,
            344, 494, 498, 498, 498, 342, 492, 500, 500, 500, 341, 338, 477, 501, 501, 501, 333, 332, 498, 502, 502,
            502, 503, 503, 503, 330, 503, 326, 324, 503, 507, 507, 507, 508, 508, 508, 516, 516, 516, 518, 518, 518,
            519, 519, 519, 507, 323, 321, 508, 520, 520, 520, 516, 320, 315, 518, 527, 527,

            527, 528, 528, 528, 529, 529, 529, 520, 529, 314, 313, 529, 311, 527, 310, 309, 528, 532, 532, 532, 534,
            534, 534, 535, 535, 535, 308, 535, 307, 306, 535, 536, 536, 536, 305, 534, 302, 537, 537, 537, 301, 537,
            300, 520, 537, 298, 536, 542, 542, 542, 543, 543, 543, 544, 544, 544, 545, 545, 545, 547, 547, 547, 542,
            294, 292, 543, 288, 282, 544, 548, 548, 548, 545, 550, 550, 550, 554, 554, 554, 555, 555, 555, 579, 579,
            579, 548, 556, 556, 556, 550, 556, 554, 281, 556, 555, 557, 557, 557, 579, 557,

            280, 279, 557, 560, 560, 560, 562, 562, 562, 563, 563, 563, 278, 563, 277, 276, 563, 275, 560, 272, 271,
            562, 566, 566, 566, 270, 566, 269, 266, 566, 573, 573, 573, 574, 574, 574, 265, 574, 264, 263, 574, 575,
            575, 575, 262, 573, 576, 576, 576, 261, 576, 260, 257, 576, 256, 255, 575, 577, 577, 577, 578, 578, 578,
            254, 578, 253, 252, 578, 582, 582, 582, 251, 577, 585, 585, 585, 586, 586, 586, 587, 587, 587, 250, 587,
            582, 249, 587, 248, 585, 246, 245, 586, 588, 588, 588, 244, 588, 243, 242, 588,

            238, 582, 591, 591, 591, 592, 592, 592, 236, 592, 235, 234, 592, 594, 594, 594, 233, 591, 595, 595, 595,
            232, 595, 231, 228, 595, 227, 226, 594, 600, 600, 600, 223, 600, 222, 221, 600, 603, 603, 603, 220, 603,
            219, 218, 603, 606, 606, 606, 217, 606, 216, 213, 606, 612, 612, 612, 613, 613, 613, 212, 613, 211, 210,
            613, 209, 614, 614, 614, 612, 614, 208, 204, 614, 617, 617, 617, 203, 617, 202, 201, 617, 621, 621, 621,
            200, 621, 199, 198, 621, 643, 643, 643, 197, 643, 196, 195, 643, 665, 665, 665,

            681, 681, 681, 682, 682, 682, 683, 683, 683, 194, 193, 192, 665, 665, 191, 190, 681, 189, 682, 682, 188,
            683, 683, 684, 684, 684, 185, 684, 184, 183, 684, 698, 698, 698, 699, 699, 699, 182, 181, 684, 175, 700,
            700, 700, 174, 700, 172, 698, 700, 699, 699, 701, 701, 701, 169, 701, 168, 700, 701, 698, 164, 736, 736,
            736, 753, 753, 753, 701, 702, 702, 702, 702, 702, 702, 702, 702, 702, 736, 736, 702, 753, 160, 702, 702,
            702, 702, 702, 747, 747, 747, 152, 747, 148, 141, 747, 742, 742, 742, 140, 139,

            702, 702, 703, 703, 703, 703, 703, 703, 703, 703, 703, 742, 138, 703, 137, 133, 703, 703, 703, 703, 703,
            718, 718, 718, 125, 718, 124, 123, 718, 750, 750, 750, 742, 750, 703, 703, 750, 718, 721, 721, 721, 721,
            721, 721, 721, 721, 721, 122, 121, 721, 117, 106, 721, 721, 721, 721, 721, 105, 104, 103, 102, 97,  93,
            92,  91,  85,  743, 743, 743, 84,  721, 721, 722, 722, 722, 722, 722, 722, 722, 722, 722, 743, 82,  722,
            79,  67,  722, 722, 722, 722, 722, 746, 746, 746, 754, 754, 754, 0,   754, 0,

            0,   754, 0,   0,   722, 722, 746, 771, 771, 771, 754, 772, 772, 772, 0,   0,   0,   0,   0,   0,   0,
            0,   0,   771, 0,   0,   0,   772, 775, 775, 775, 775, 775, 775, 775, 776, 776, 776, 776, 776, 776, 776,
            777, 777, 777, 777, 777, 777, 777, 778, 778, 778, 778, 778, 778, 778, 779, 779, 779, 779, 779, 779, 779,
            780, 780, 780, 780, 780, 780, 780, 781, 781, 781, 781, 781, 781, 781, 782, 782, 782, 782, 782, 782, 782,
            783, 783, 783, 783, 783, 783, 783, 784, 784, 784, 784, 784, 784, 784, 785, 785,

            785, 785, 785, 785, 785, 786, 786, 786, 786, 786, 786, 786, 787, 787, 787, 787, 787, 787, 787, 788, 788,
            788, 788, 788, 788, 788, 789, 789, 789, 0,   789, 790, 790, 790, 0,   790, 791, 791, 791, 0,   791, 792,
            792, 792, 0,   792, 793, 793, 793, 0,   793, 794, 794, 794, 794, 794, 0,   794, 795, 0,   795, 796, 0,
            796, 797, 0,   797, 798, 0,   798, 799, 0,   799, 800, 800, 800, 800, 800, 800, 800, 801, 0,   0,   801,
            802, 802, 802, 802, 802, 802, 803, 803, 803, 803, 803, 803, 804, 804, 804, 804,

            804, 804, 805, 805, 805, 805, 805, 805, 806, 806, 806, 806, 806, 806, 807, 807, 807, 807, 807, 807, 807,
            808, 808, 808, 808, 808, 808, 808, 809, 809, 809, 809, 809, 809, 809, 810, 810, 810, 810, 810, 810, 810,
            811, 811, 811, 811, 811, 811, 811, 812, 812, 812, 812, 812, 812, 812, 813, 813, 813, 813, 813, 813, 813,
            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,
            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,

            774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774, 774,
            774, 774};

        /* Table of booleans, true if rule could match eol. */
        static const flex_int32_t yy_rule_can_match_eol[141] = {
            0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 1, 1, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
            1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 1, 1,
            1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0,
            1, 1, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0,
        };

        static yy_state_type yy_last_accepting_state;
        static char* yy_last_accepting_cpos;

        extern int yy_flex_debug;
        int yy_flex_debug = 0;

        /* The intent behind this definition is that it'll catch
         * any uses of REJECT which flex missed.
         */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
/* Validating XML processor for src/simdag/dax.dtd.
 *
 * This program was generated with the FleXML XML processor generator.
 * FleXML is Copyright (C) 1999-2005 Kristoffer Rose.  All rights reserved.
 * FleXML is Copyright (C) 2003-2013 Martin Quinson.  All rights reserved.
 * (1.9.6).
 * 
 * There are two, intertwined parts to this program, part A and part B.
 *
 * Part A
 * ------
 * 
 * Some parts, here collectively called "Part A", are found in the 
 * FleXML package.  They are Copyright (C) 1999-2005 Kristoffer Rose
 * and Copyright (C) 2003-2013 Martin Quinson. All rights reserved.
 *
 * You can redistribute, use, perform, display and/or modify "Part A"
 * provided the following two conditions hold:
 *
 * 1. The program is distributed WITHOUT ANY WARRANTY from the author of
 *    FleXML; without even the implied warranty of MERCHANTABILITY or
 *    FITNESS FOR A PARTICULAR PURPOSE.
 *
 * 2. The program distribution conditions do not in any way affect the
 *    distribution conditions of the FleXML system used to generate this
 *    file or any version of FleXML derived from that system.
 *
 * Notice that these are explicit rights granted to you for files
 * generated by the FleXML system.  For your rights in connection with
 * the FleXML system itself please consult the GNU General Public License.
 * 
 * Part B
 * ------
 * 
 * The other parts, here collectively called "Part B", and which came 
 * from the DTD used by FleXML to generate this program, can be 
 * distributed (or not, as the case may be) under the terms of whoever
 * wrote them, provided these terms respect and obey the two conditions 
 * above under the heading "Part A".
 *
 * The author of and contributors to FleXML specifically disclaim
 * any copyright interest in "Part B", unless "Part B" was written 
 * by the author of or contributors to FleXML.
 * 
 */

/* Version strings. */
const char dax__flexml_version[] = "1.9.6";

/* ANSI headers. */
#include <stdlib.h> /* for realloc() -- needed here when using flex 2.5.4 */
#include <stdio.h>
#include <string.h>
#include <assert.h>
#include <stdarg.h>
#include <ctype.h>
     
#if defined(_WIN32) || defined(__WIN32__) || defined(WIN32) || defined(__TOS_WIN__)
# ifndef __STRICT_ANSI__
#  include <io.h>
#  include <process.h>
# endif
#else
# include <unistd.h>
#endif
     
#ifndef FLEXML_INDEXSTACKSIZE
#define FLEXML_INDEXSTACKSIZE 1000
#endif

/* Generated definitions. */
#define FLEXML_yylineno
#ifndef FLEXML_BUFFERSTACKSIZE
#define FLEXML_BUFFERSTACKSIZE 1000000
#endif
#define FLEXML_NEED_BUFFERLIT

/* XML processor api. */
/* FleXML-provided data. */
int dax__pcdata_ix;
extern char *dax__bufferstack;
#define dax__pcdata (dax__bufferstack + dax__pcdata_ix)
AT_dax__job_name AX_dax__job_name;
#define A_dax__job_name (dax__bufferstack + AX_dax__job_name)
short int dax__job_name_isset;
AT_dax__uses_link AX_dax__uses_link;
#define A_dax__uses_link AX_dax__uses_link
short int dax__uses_link_isset;
AT_dax__uses_transfer AX_dax__uses_transfer;
#define A_dax__uses_transfer AX_dax__uses_transfer
short int dax__uses_transfer_isset;
AT_dax__adag_xmlns_c_xsi AX_dax__adag_xmlns_c_xsi;
#define A_dax__adag_xmlns_c_xsi (dax__bufferstack + AX_dax__adag_xmlns_c_xsi)
short int dax__adag_xmlns_c_xsi_isset;
AT_dax__uses_optional AX_dax__uses_optional;
#define A_dax__uses_optional AX_dax__uses_optional
short int dax__uses_optional_isset;
AT_dax__parent_ref AX_dax__parent_ref;
#define A_dax__parent_ref (dax__bufferstack + AX_dax__parent_ref)
short int dax__parent_ref_isset;
AT_dax__uses_register AX_dax__uses_register;
#define A_dax__uses_register AX_dax__uses_register
short int dax__uses_register_isset;
AT_dax__uses_file AX_dax__uses_file;
#define A_dax__uses_file (dax__bufferstack + AX_dax__uses_file)
short int dax__uses_file_isset;
AT_dax__uses_type AX_dax__uses_type;
#define A_dax__uses_type (dax__bufferstack + AX_dax__uses_type)
short int dax__uses_type_isset;
AT_dax__adag_xmlns AX_dax__adag_xmlns;
#define A_dax__adag_xmlns (dax__bufferstack + AX_dax__adag_xmlns)
short int dax__adag_xmlns_isset;
AT_dax__adag_fileCount AX_dax__adag_fileCount;
#define A_dax__adag_fileCount (dax__bufferstack + AX_dax__adag_fileCount)
short int dax__adag_fileCount_isset;
AT_dax__job_version AX_dax__job_version;
#define A_dax__job_version (dax__bufferstack + AX_dax__job_version)
short int dax__job_version_isset;
AT_dax__adag_count AX_dax__adag_count;
#define A_dax__adag_count (dax__bufferstack + AX_dax__adag_count)
short int dax__adag_count_isset;
AT_dax__child_ref AX_dax__child_ref;
#define A_dax__child_ref (dax__bufferstack + AX_dax__child_ref)
short int dax__child_ref_isset;
AT_dax__adag_xsi_c_schemaLocation AX_dax__adag_xsi_c_schemaLocation;
#define A_dax__adag_xsi_c_schemaLocation (dax__bufferstack + AX_dax__adag_xsi_c_schemaLocation)
short int dax__adag_xsi_c_schemaLocation_isset;
AT_dax__job_runtime AX_dax__job_runtime;
#define A_dax__job_runtime (dax__bufferstack + AX_dax__job_runtime)
short int dax__job_runtime_isset;
AT_dax__adag_childCount AX_dax__adag_childCount;
#define A_dax__adag_childCount (dax__bufferstack + AX_dax__adag_childCount)
short int dax__adag_childCount_isset;
AT_dax__uses_size AX_dax__uses_size;
#define A_dax__uses_size (dax__bufferstack + AX_dax__uses_size)
short int dax__uses_size_isset;
AT_dax__job_namespace AX_dax__job_namespace;
#define A_dax__job_namespace (dax__bufferstack + AX_dax__job_namespace)
short int dax__job_namespace_isset;
AT_dax__adag_jobCount AX_dax__adag_jobCount;
#define A_dax__adag_jobCount (dax__bufferstack + AX_dax__adag_jobCount)
short int dax__adag_jobCount_isset;
AT_dax__job_id AX_dax__job_id;
#define A_dax__job_id (dax__bufferstack + AX_dax__job_id)
short int dax__job_id_isset;
AT_dax__job_level AX_dax__job_level;
#define A_dax__job_level (dax__bufferstack + AX_dax__job_level)
short int dax__job_level_isset;
AT_dax__adag_index AX_dax__adag_index;
#define A_dax__adag_index (dax__bufferstack + AX_dax__adag_index)
short int dax__adag_index_isset;
AT_dax__adag_name AX_dax__adag_name;
#define A_dax__adag_name (dax__bufferstack + AX_dax__adag_name)
short int dax__adag_name_isset;
AT_dax__adag_version AX_dax__adag_version;
#define A_dax__adag_version (dax__bufferstack + AX_dax__adag_version)
short int dax__adag_version_isset;

/* XML state. */
#ifdef FLEX_DEBUG
# define ENTER(state)	debug_enter(state,#state)
# define LEAVE		debug_leave()
# define SET(state)	debug_set(state,#state)
  static void debug_enter(int, const char*);
  static void debug_leave(void);
  static void debug_set(int, const char*);
#else
# define ENTER(state)	(yy_push_state(state))
# define LEAVE		(yy_pop_state())
# define SET(state)	BEGIN(state)
#endif

/* Generic actions. */
#define SKIP	/*skip*/
#define SUCCEED        CLEANUP; return 0

#define FAIL	return fail
static int fail(const char*, ...);

enum {flexml_max_err_msg_size = 512};
static char flexml_err_msg[flexml_max_err_msg_size];
const char * dax__parse_err_msg()
{
    return flexml_err_msg;
}
static void reset_dax__parse_err_msg()
{
    flexml_err_msg[0] = '\0';
}

/* Cleanup */
static void cleanup(void);
#define CLEANUP  cleanup()

/* Text buffer stack handling. */
char *dax__bufferstack = NULL;
static int blimit = FLEXML_BUFFERSTACKSIZE;
static int bnext = 1;

static int *indexstack = NULL;
static int ilimit = FLEXML_INDEXSTACKSIZE;
static int inext = 1;

#define BUFFERSET(P)  (P = bnext)
#define BUFFERPUTC(C) (ck_blimit(), dax__bufferstack[bnext++] = (C))
#define BUFFERDONE    (BUFFERPUTC('\0'))

#define BUFFERLITERAL(C, P) dax__bufferliteral(C, &(P), yytext)

/* after this is called, there are at least 2 slots left in the stack */
static int ck_blimit()
{
     if (bnext >= blimit) {
	 blimit += FLEXML_BUFFERSTACKSIZE + 2;
	 {
	     char *temp = (char *) realloc(dax__bufferstack, blimit);
	     assert(temp);
	     dax__bufferstack = temp;
	 }
     }
     return 0;
}

/* after this is called, there are at least 2 slots left in the stack */
static int ck_ilimit()
{
     if (inext >= ilimit) {
	 ilimit += FLEXML_INDEXSTACKSIZE + 2;
	 {
	     int *temp = (int *) realloc(indexstack, ilimit);
	     assert(temp);
	     indexstack = temp;
	 }
     }
     return 0;
}

#ifdef FLEXML_NEED_BUFFERLIT
static void dax__bufferliteral(char c, int* pp, const char* text)
{
   BUFFERSET(*pp);
   if (c) {
      const char *s = strchr(text, c), *e = strrchr(text, c);
      assert(s && e && s <= e);
      ++s;
      while (s < e) {
	 if (isspace(*s)) {
	    BUFFERPUTC(' ');
	    do ++s; while (s < e && isspace(*s));
	 } else
	   BUFFERPUTC(*s++);
      }
   } else {
      const char *s = text;
      while (*s)
	BUFFERPUTC(*s++);
   }
   BUFFERDONE;
}
#endif

static void pushbuffer(int p)
{
    ck_ilimit();
    indexstack[inext++] = p;
    indexstack[inext++] = bnext;    
}

static int popbuffer(void)
{
    assert(inext >= 2);
    bnext = indexstack[--inext];
    return indexstack[--inext];
}

/* General internal entities are `unput' back onto the input stream... */
#define ENTITYTEXT(T) \
  { char *s = (T), *e = s+strlen(s);\
    while (--e >= s) { unput(*e); }}

/* Flex standard options. */
#define YY_NO_INPUT 1
/* Flex user-requested options. */
/* XML character classes (currently restricted to ASCII). */
/* "Common syntactic structures." */
/* "Names and Tokens." */
/* Miscellaneous. */
/* Parser states (flex `exclusive start conditions'):
 *
 * PROLOG	the XML prolog of the document before <?xml...>
 * DOCTYPE	the XML prolog of the document after <?xml...>
 * EPILOG	after the root element
 * INCOMMENT	inside an XML comment <!--....-->
 * INPI		inside an XML PI <?...?>
 * VALUE1	inside a '...'-delimited literal
 * VALUE2	inside a "..."-delimited literal
 * CDATA	inside a <![CDATA[...] ]> section.
 * ROOT_<tag>	expect root element <tag>
 * AL_<tag>	inside the attribute list for <tag>
 * IN_<tag>	inside a <tag> with element contents (ready for end tag)
 * IMPOSSIBLE	dummy to permit disabling rules; must be last
 */

/* State names. */
const char* *dax__statenames=NULL;

#define INITIAL 0
#define PROLOG 1
#define DOCTYPE 2
#define EPILOG 3
#define INCOMMENT 4
#define INPI 5
#define VALUE1 6
#define VALUE2 7
#define CDATA 8
#define ROOT_dax__adag 9
#define AL_dax__adag 10
#define S_dax__adag 11
#define S_dax__adag_1 12
#define S_dax__adag_2 13
#define S_dax__adag_3 14
#define S_dax__adag_4 15
#define S_dax__adag_5 16
#define E_dax__adag 17
#define AL_dax__job 18
#define S_dax__job 19
#define S_dax__job_1 20
#define S_dax__job_2 21
#define E_dax__job 22
#define AL_dax__uses 23
#define E_dax__uses 24
#define AL_dax__child 25
#define S_dax__child 26
#define S_dax__child_1 27
#define S_dax__child_2 28
#define E_dax__child 29
#define AL_dax__parent 30
#define E_dax__parent 31
#define IMPOSSIBLE 32

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#if defined(_WIN32)
#  ifndef __STRICT_ANSI__
#    include <io.h>
#    include <process.h>
#  endif
#else
#  include <unistd.h>
#endif
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state ( int _new_state );
    
    static void yy_pop_state ( void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{

 /* Bypass Flex's default INITIAL state and begin by parsing the XML prolog. */
 SET(PROLOG);
 reset_dax__parse_err_msg();
 dax__bufferstack = (char *) malloc(FLEXML_BUFFERSTACKSIZE);
 assert(dax__bufferstack);
 #ifdef FLEX_DEBUG
 {
     int i;
     for (i = 0; i < blimit; i++) {
         dax__bufferstack[i] = '\377';
     }
 }
 #endif
 dax__bufferstack[0] = '\0';
 indexstack = (int *) malloc(FLEXML_INDEXSTACKSIZE * sizeof(int));
 assert(indexstack);
 indexstack[0] = 0;

  /* FleXML_init */
  bnext = inext = 1;
  dax__bufferliteral('\0', &bnext, "http://pegasus.isi.edu/schema/DAX");
  dax__bufferliteral('\0', &bnext, "http://www.w3.org/2001/XMLSchema-instance");
  dax__bufferliteral('\0', &bnext, "http://pegasus.isi.edu/schema/DAX http://pegasus.isi.edu/schema/dax-2.1.xsd");
  dax__bufferliteral('\0', &bnext, "1.0");
  dax__bufferliteral('\0', &bnext, "0.0");
  dax__bufferliteral('\0', &bnext, "data");
  if(!dax__statenames) {dax__statenames= (const char **)calloc(IMPOSSIBLE,sizeof(char*));
  dax__statenames[PROLOG] = NULL;
  dax__statenames[DOCTYPE] = NULL;
  dax__statenames[EPILOG] = NULL;
  dax__statenames[INCOMMENT] = NULL;
  dax__statenames[INPI] = NULL;
  dax__statenames[VALUE1] = NULL;
  dax__statenames[VALUE2] = NULL;
  dax__statenames[CDATA] = NULL;
  dax__statenames[ROOT_dax__adag] = NULL;
  dax__statenames[AL_dax__adag] = NULL;
  dax__statenames[S_dax__adag] = "adag";
  dax__statenames[S_dax__adag_1] = "adag";
  dax__statenames[S_dax__adag_2] = "adag";
  dax__statenames[S_dax__adag_3] = "adag";
  dax__statenames[S_dax__adag_4] = "adag";
  dax__statenames[S_dax__adag_5] = "adag";
  dax__statenames[E_dax__adag] = "adag";
  dax__statenames[AL_dax__job] = NULL;
  dax__statenames[S_dax__job] = "job";
  dax__statenames[S_dax__job_1] = "job";
  dax__statenames[S_dax__job_2] = "job";
  dax__statenames[E_dax__job] = "job";
  dax__statenames[AL_dax__uses] = NULL;
  dax__statenames[E_dax__uses] = "uses";
  dax__statenames[AL_dax__child]       = NULL;
  dax__statenames[S_dax__child]        = "child";
  dax__statenames[S_dax__child_1]      = "child";
  dax__statenames[S_dax__child_2]      = "child";
  dax__statenames[E_dax__child]        = "child";
  dax__statenames[AL_dax__parent]      = NULL;
  dax__statenames[E_dax__parent]       = "parent";
  }

 /* COMMENTS and PIs: handled uniformly for efficiency. */

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 775 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
                } while (yy_base[yy_current_state] != 2164);

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
ENTER(INCOMMENT);
	YY_BREAK
case 2:
YY_RULE_SETUP
ENTER(INPI);
	YY_BREAK

case 3:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
case 4:
case 5:
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
case YY_STATE_EOF(INCOMMENT):
FAIL("EOF in comment.");
	YY_BREAK

case 7:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
case 8:
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
case YY_STATE_EOF(INPI):
FAIL("EOF in PI (processing instruction).");
	YY_BREAK

/* SPACES: skipped uniformly */
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
SKIP;
	YY_BREAK
/* PROLOG: determine root element and process it. */

case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
SET(ROOT_dax__adag); 
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
FAIL("Bad declaration %s.",yytext);
	YY_BREAK

case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
SET(ROOT_dax__adag);
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
FAIL("Bad declaration %s.",yytext);
	YY_BREAK
case 15:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in prolog.", yytext[0]);
	YY_BREAK
case YY_STATE_EOF(PROLOG):
case YY_STATE_EOF(DOCTYPE):
FAIL("EOF in prolog.");
	YY_BREAK

/* RULES DERIVED FROM DTD. */
/* <!-- Small DTD for DAX files. -->  */
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <adag> is not allowed here.");
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
{
  AX_dax__adag_xmlns = 1;
  dax__adag_xmlns_isset = 0;
  AX_dax__adag_xmlns_c_xsi = 35;
  dax__adag_xmlns_c_xsi_isset = 0;
  AX_dax__adag_xsi_c_schemaLocation = 77;
  dax__adag_xsi_c_schemaLocation_isset = 0;
  AX_dax__adag_version                 = 153;
  dax__adag_version_isset              = 0;
  AX_dax__adag_count                   = 0;
  dax__adag_count_isset                = 0;
  AX_dax__adag_index                   = 0;
  dax__adag_index_isset                = 0;
  AX_dax__adag_name                    = 0;
  dax__adag_name_isset                 = 0;
  AX_dax__adag_jobCount                = 0;
  dax__adag_jobCount_isset             = 0;
  AX_dax__adag_fileCount               = 0;
  dax__adag_fileCount_isset            = 0;
  AX_dax__adag_childCount              = 0;
  dax__adag_childCount_isset           = 0;
  ENTER(AL_dax__adag); pushbuffer(0);
  }
	YY_BREAK

case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
if (dax__adag_xmlns_isset != 0) {
  FAIL("Multiple definition of attribute xmlns in <dax__adag>");
}
dax__adag_xmlns_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_xmlns);
YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
if (dax__adag_xmlns_isset != 0) {
  FAIL("Multiple definition of attribute xmlns in <dax__adag>");
}
dax__adag_xmlns_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_xmlns);
YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
if (dax__adag_xmlns_c_xsi_isset != 0) {
  FAIL("Multiple definition of attribute xmlns:xsi in <dax__adag>");
}
dax__adag_xmlns_c_xsi_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_xmlns_c_xsi);
YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
if (dax__adag_xmlns_c_xsi_isset != 0) {
  FAIL("Multiple definition of attribute xmlns:xsi in <dax__adag>");
}
dax__adag_xmlns_c_xsi_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_xmlns_c_xsi);
YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
if (dax__adag_xsi_c_schemaLocation_isset != 0) {
  FAIL("Multiple definition of attribute xsi:schemaLocation in <dax__adag>");
}
dax__adag_xsi_c_schemaLocation_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_xsi_c_schemaLocation);
YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
if (dax__adag_xsi_c_schemaLocation_isset != 0) {
  FAIL("Multiple definition of attribute xsi:schemaLocation in <dax__adag>");
}
dax__adag_xsi_c_schemaLocation_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_xsi_c_schemaLocation);
YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
if (dax__adag_version_isset != 0) {
  FAIL("Multiple definition of attribute version in <dax__adag>");
}
dax__adag_version_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_version);
YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
if (dax__adag_version_isset != 0) {
  FAIL("Multiple definition of attribute version in <dax__adag>");
}
dax__adag_version_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_version);
YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
if (dax__adag_count_isset != 0) {
  FAIL("Multiple definition of attribute count in <dax__adag>");
}
dax__adag_count_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_count);
YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
if (dax__adag_count_isset != 0) {
  FAIL("Multiple definition of attribute count in <dax__adag>");
}
dax__adag_count_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_count);
YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
if (dax__adag_index_isset != 0) {
  FAIL("Multiple definition of attribute index in <dax__adag>");
}
dax__adag_index_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_index);
YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
if (dax__adag_index_isset != 0) {
  FAIL("Multiple definition of attribute index in <dax__adag>");
}
dax__adag_index_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_index);
YY_BREAK
case 30:
/* rule 30 can match eol */
YY_RULE_SETUP
if (dax__adag_name_isset != 0) {
  FAIL("Multiple definition of attribute name in <dax__adag>");
}
dax__adag_name_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_name);
YY_BREAK
case 31:
/* rule 31 can match eol */
YY_RULE_SETUP
if (dax__adag_name_isset != 0) {
  FAIL("Multiple definition of attribute name in <dax__adag>");
}
dax__adag_name_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_name);
YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
if (dax__adag_jobCount_isset != 0) {
  FAIL("Multiple definition of attribute jobCount in <dax__adag>");
}
dax__adag_jobCount_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_jobCount);
YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
if (dax__adag_jobCount_isset != 0) {
  FAIL("Multiple definition of attribute jobCount in <dax__adag>");
}
dax__adag_jobCount_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_jobCount);
YY_BREAK
case 34:
/* rule 34 can match eol */
YY_RULE_SETUP
if (dax__adag_fileCount_isset != 0) {
  FAIL("Multiple definition of attribute fileCount in <dax__adag>");
}
dax__adag_fileCount_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_fileCount);
YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
if (dax__adag_fileCount_isset != 0) {
  FAIL("Multiple definition of attribute fileCount in <dax__adag>");
}
dax__adag_fileCount_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_fileCount);
YY_BREAK
case 36:
/* rule 36 can match eol */
YY_RULE_SETUP
if (dax__adag_childCount_isset != 0) {
  FAIL("Multiple definition of attribute childCount in <dax__adag>");
}
dax__adag_childCount_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__adag_childCount);
YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
if (dax__adag_childCount_isset != 0) {
  FAIL("Multiple definition of attribute childCount in <dax__adag>");
}
dax__adag_childCount_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__adag_childCount);
YY_BREAK
case 38:
YY_RULE_SETUP
{
  LEAVE; STag_dax__adag();dax__pcdata_ix = 0; ENTER(S_dax__adag);
 }
	YY_BREAK
case 39:
YY_RULE_SETUP
{
  LEAVE; STag_dax__adag(); dax__pcdata_ix = 0; ETag_dax__adag(); popbuffer(); /* attribute */
  switch (YY_START) {
   case ROOT_dax__adag: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 40:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of adag element.", yytext[0]);
	YY_BREAK
case 41:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `adag' element start tag.",yytext);
	YY_BREAK
case YY_STATE_EOF(AL_dax__adag):
FAIL("EOF in attribute list of `adag' element.");
	YY_BREAK

case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__adag();
  popbuffer(); /* attribute */
  switch (YY_START) {
   case ROOT_dax__adag: SET(EPILOG); break;
  }
 }
	YY_BREAK
case 43:
/* rule 43 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</adag>' expected.",yytext);
	YY_BREAK
case 44:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</adag>' expected.",yytext[0]);
	YY_BREAK
case YY_STATE_EOF(S_dax__adag_1):
case YY_STATE_EOF(S_dax__adag_3):
case YY_STATE_EOF(S_dax__adag_5):
case YY_STATE_EOF(S_dax__adag):
case YY_STATE_EOF(E_dax__adag):
  FAIL("Premature EOF: `</adag>' expected.");
  YY_BREAK

case 45:
/* rule 45 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <job> is not allowed here.");
YY_BREAK
case 46:
/* rule 46 can match eol */
YY_RULE_SETUP
{
  AX_dax__job_id           = 0;
  dax__job_id_isset        = 0;
  AX_dax__job_namespace    = 0;
  dax__job_namespace_isset = 0;
  AX_dax__job_name         = 0;
  dax__job_name_isset      = 0;
  AX_dax__job_version      = 157;
  dax__job_version_isset   = 0;
  AX_dax__job_runtime      = 0;
  dax__job_runtime_isset   = 0;
  AX_dax__job_level        = 0;
  dax__job_level_isset     = 0;
  ENTER(AL_dax__job);
  pushbuffer(0);
  }
	YY_BREAK

case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
if (dax__job_id_isset != 0) {
  FAIL("Multiple definition of attribute id in <dax__job>");
}
dax__job_id_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__job_id);
YY_BREAK
case 48:
/* rule 48 can match eol */
YY_RULE_SETUP
if (dax__job_id_isset != 0) {
  FAIL("Multiple definition of attribute id in <dax__job>");
}
dax__job_id_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__job_id);
YY_BREAK
case 49:
  /* rule 49 can match eol */
  YY_RULE_SETUP
  if (dax__job_namespace_isset != 0) {
    FAIL("Multiple definition of attribute namespace in <dax__job>");
  }
  dax__job_namespace_isset = 1;
  ENTER(VALUE1);
  BUFFERSET(AX_dax__job_namespace);
  YY_BREAK
case 50:
  /* rule 50 can match eol */
  YY_RULE_SETUP
  if (dax__job_namespace_isset != 0) {
    FAIL("Multiple definition of attribute namespace in <dax__job>");
  }
  dax__job_namespace_isset = 1;
  ENTER(VALUE2);
  BUFFERSET(AX_dax__job_namespace);
  YY_BREAK
case 51:
  /* rule 51 can match eol */
  YY_RULE_SETUP
  if (dax__job_name_isset != 0) {
    FAIL("Multiple definition of attribute name in <dax__job>");
  }
  dax__job_name_isset = 1;
  ENTER(VALUE1);
  BUFFERSET(AX_dax__job_name);
  YY_BREAK
case 52:
  /* rule 52 can match eol */
  YY_RULE_SETUP
  if (dax__job_name_isset != 0) {
    FAIL("Multiple definition of attribute name in <dax__job>");
  }
  dax__job_name_isset = 1;
  ENTER(VALUE2);
  BUFFERSET(AX_dax__job_name);
  YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
if (dax__job_version_isset != 0) {
  FAIL("Multiple definition of attribute version in <dax__job>");
}
dax__job_version_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__job_version);
YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
if (dax__job_version_isset != 0) {
  FAIL("Multiple definition of attribute version in <dax__job>");
}
dax__job_version_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__job_version);
YY_BREAK
case 55:
  /* rule 55 can match eol */
  YY_RULE_SETUP
  if (dax__job_runtime_isset != 0) {
    FAIL("Multiple definition of attribute runtime in <dax__job>");
  }
  dax__job_runtime_isset = 1;
  ENTER(VALUE1);
  BUFFERSET(AX_dax__job_runtime);
  YY_BREAK
case 56:
/* rule 56 can match eol */
YY_RULE_SETUP
if (dax__job_runtime_isset != 0) {
  FAIL("Multiple definition of attribute runtime in <dax__job>");
}
dax__job_runtime_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__job_runtime);
YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
if (dax__job_level_isset != 0) {
  FAIL("Multiple definition of attribute level in <dax__job>");
}
dax__job_level_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__job_level);
YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
if (dax__job_level_isset != 0) {
  FAIL("Multiple definition of attribute level in <dax__job>");
}
dax__job_level_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__job_level);
YY_BREAK
case 59:
YY_RULE_SETUP
{
  if (!AX_dax__job_id)
    FAIL("Required attribute `id' not set for `job' element.");
  if (!AX_dax__job_name)
    FAIL("Required attribute `name' not set for `job' element.");
  if (!AX_dax__job_runtime)
    FAIL("Required attribute `runtime' not set for `job' element.");
  LEAVE;
  STag_dax__job();
  dax__pcdata_ix = 0;
  ENTER(S_dax__job);
}
        YY_BREAK
case 60:
YY_RULE_SETUP
{
  if (!AX_dax__job_id)
    FAIL("Required attribute `id' not set for `job' element.");
  if (!AX_dax__job_name)
    FAIL("Required attribute `name' not set for `job' element.");
  if (!AX_dax__job_runtime)
    FAIL("Required attribute `runtime' not set for `job' element.");
  LEAVE;
  STag_dax__job();
  dax__pcdata_ix = 0;
  ETag_dax__job();
  popbuffer(); /* attribute */
  switch (YY_START) {
    case S_dax__adag:
    case S_dax__adag_2:
    case S_dax__adag_3:
      SET(S_dax__adag_3);
      break;
  }
}
        YY_BREAK
case 61:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of job element.", yytext[0]);
YY_BREAK
case 62:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `job' element start tag.", yytext);
YY_BREAK
case YY_STATE_EOF(AL_dax__job):
  FAIL("EOF in attribute list of `job' element.");
  YY_BREAK

case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__job();
  popbuffer(); /* attribute */
  switch (YY_START) {
    case S_dax__adag:
    case S_dax__adag_2:
    case S_dax__adag_3:
      SET(S_dax__adag_3);
      break;
  }
}
        YY_BREAK
case 64:
/* rule 64 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</job>' expected.", yytext);
YY_BREAK
case 65:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</job>' expected.", yytext[0]);
YY_BREAK
case YY_STATE_EOF(S_dax__job_2):
case YY_STATE_EOF(S_dax__job):
case YY_STATE_EOF(E_dax__job):
  FAIL("Premature EOF: `</job>' expected.");
  YY_BREAK

/* <!-- ignored -->
 * <!-- ignored -->  */
case 66:
/* rule 66 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <uses> is not allowed here.");
YY_BREAK
case 67:
/* rule 67 can match eol */
YY_RULE_SETUP
{
  AX_dax__uses_file        = 0;
  dax__uses_file_isset     = 0;
  AX_dax__uses_link        = AU_dax__uses_link;
  dax__uses_link_isset     = 0;
  AX_dax__uses_register    = A_dax__uses_register_true;
  dax__uses_register_isset = 0;
  AX_dax__uses_transfer    = A_dax__uses_transfer_true;
  dax__uses_transfer_isset = 0;
  AX_dax__uses_optional    = A_dax__uses_optional_false;
  dax__uses_optional_isset = 0;
  AX_dax__uses_type        = 161;
  dax__uses_type_isset     = 0;
  AX_dax__uses_size        = 0;
  dax__uses_size_isset     = 0;
  ENTER(AL_dax__uses);
  pushbuffer(0);
}
        YY_BREAK

case 68:
/* rule 68 can match eol */
YY_RULE_SETUP
if (dax__uses_file_isset != 0) {
  FAIL("Multiple definition of attribute file in <dax__uses>");
}
dax__uses_file_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__uses_file);
YY_BREAK
case 69:
/* rule 69 can match eol */
YY_RULE_SETUP
if (dax__uses_file_isset != 0) {
  FAIL("Multiple definition of attribute file in <dax__uses>");
}
dax__uses_file_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__uses_file);
YY_BREAK
case 70:
/* rule 70 can match eol */
case 71:
  /* rule 71 can match eol */
  YY_RULE_SETUP
  A_dax__uses_link = A_dax__uses_link_input;
  YY_BREAK
case 72:
/* rule 72 can match eol */
case 73:
  /* rule 73 can match eol */
  YY_RULE_SETUP
  A_dax__uses_link = A_dax__uses_link_output;
  YY_BREAK
case 74:
/* rule 74 can match eol */
case 75:
/* rule 75 can match eol */
YY_RULE_SETUP
A_dax__uses_register = A_dax__uses_register_false;
YY_BREAK
case 76:
/* rule 76 can match eol */
case 77:
/* rule 77 can match eol */
YY_RULE_SETUP
A_dax__uses_register = A_dax__uses_register_true;
YY_BREAK
case 78:
/* rule 78 can match eol */
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
A_dax__uses_transfer = A_dax__uses_transfer_false;
YY_BREAK
case 80:
/* rule 80 can match eol */
case 81:
  /* rule 81 can match eol */
  YY_RULE_SETUP
  A_dax__uses_transfer = A_dax__uses_transfer_true;
  YY_BREAK
case 82:
/* rule 82 can match eol */
case 83:
  /* rule 83 can match eol */
  YY_RULE_SETUP
  A_dax__uses_optional = A_dax__uses_optional_false;
  YY_BREAK
case 84:
/* rule 84 can match eol */
case 85:
/* rule 85 can match eol */
YY_RULE_SETUP
A_dax__uses_optional = A_dax__uses_optional_true;
YY_BREAK
case 86:
/* rule 86 can match eol */
YY_RULE_SETUP
if (dax__uses_type_isset != 0) {
  FAIL("Multiple definition of attribute type in <dax__uses>");
}
dax__uses_type_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__uses_type);
YY_BREAK
case 87:
  /* rule 87 can match eol */
  YY_RULE_SETUP
  if (dax__uses_type_isset != 0) {
    FAIL("Multiple definition of attribute type in <dax__uses>");
  }
  dax__uses_type_isset = 1;
  ENTER(VALUE2);
  BUFFERSET(AX_dax__uses_type);
  YY_BREAK
case 88:
/* rule 88 can match eol */
YY_RULE_SETUP
if (dax__uses_size_isset != 0) {
  FAIL("Multiple definition of attribute size in <dax__uses>");
}
dax__uses_size_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__uses_size);
YY_BREAK
case 89:
/* rule 89 can match eol */
YY_RULE_SETUP
if (dax__uses_size_isset != 0) {
  FAIL("Multiple definition of attribute size in <dax__uses>");
}
dax__uses_size_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__uses_size);
YY_BREAK
case 90:
YY_RULE_SETUP
{
  if (!AX_dax__uses_file)
    FAIL("Required attribute `file' not set for `uses' element.");
  if (!AX_dax__uses_size)
    FAIL("Required attribute `size' not set for `uses' element.");
  LEAVE;
  STag_dax__uses();
  dax__pcdata_ix = 0;
  ENTER(E_dax__uses);
}
        YY_BREAK
case 91:
YY_RULE_SETUP
{
  if (!AX_dax__uses_file)
    FAIL("Required attribute `file' not set for `uses' element.");
  if (!AX_dax__uses_size)
    FAIL("Required attribute `size' not set for `uses' element.");
  LEAVE;
  STag_dax__uses();
  dax__pcdata_ix = 0;
  ETag_dax__uses();
  popbuffer(); /* attribute */
  switch (YY_START) {
    case S_dax__job_1:
    case S_dax__job_2:
    case S_dax__job:
      SET(S_dax__job_2);
      break;
  }
}
        YY_BREAK
case 92:
  YY_RULE_SETUP
  FAIL("Unexpected character `%c' in attribute list of uses element.", yytext[0]);
  YY_BREAK
case 93:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `uses' element start tag.", yytext);
YY_BREAK
case YY_STATE_EOF(AL_dax__uses):
  FAIL("EOF in attribute list of `uses' element.");
  YY_BREAK

case 94:
/* rule 94 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__uses();
  popbuffer(); /* attribute */
  switch (YY_START) {
    case S_dax__job_1:
    case S_dax__job_2:
    case S_dax__job:
      SET(S_dax__job_2);
      break;
  }
}
YY_BREAK
case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</uses>' expected.", yytext);
YY_BREAK
case 96:
  YY_RULE_SETUP
  FAIL("Unexpected character `%c': `</uses>' expected.", yytext[0]);
  YY_BREAK
case YY_STATE_EOF(E_dax__uses):
  FAIL("Premature EOF: `</uses>' expected.");
  YY_BREAK

case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <child> is not allowed here.");
YY_BREAK
case 98:
/* rule 98 can match eol */
YY_RULE_SETUP
{
  AX_dax__child_ref    = 0;
  dax__child_ref_isset = 0;
  ENTER(AL_dax__child);
  pushbuffer(0);
}
YY_BREAK

case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
if (dax__child_ref_isset != 0) {
  FAIL("Multiple definition of attribute ref in <dax__child>");
}
dax__child_ref_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__child_ref);
YY_BREAK
case 100:
/* rule 100 can match eol */
YY_RULE_SETUP
if (dax__child_ref_isset != 0) {
  FAIL("Multiple definition of attribute ref in <dax__child>");
}
dax__child_ref_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__child_ref);
YY_BREAK
case 101:
YY_RULE_SETUP
{
  if (!AX_dax__child_ref)
    FAIL("Required attribute `ref' not set for `child' element.");
  LEAVE;
  STag_dax__child();
  dax__pcdata_ix = 0;
  ENTER(S_dax__child);
}
        YY_BREAK
case 102:
  YY_RULE_SETUP
  {
    if (!AX_dax__child_ref)
      FAIL("Required attribute `ref' not set for `child' element.");
    LEAVE;
    STag_dax__child();
    dax__pcdata_ix = 0;
    ETag_dax__child();
    popbuffer(); /* attribute */
    switch (YY_START) {
      case S_dax__adag_1:
      case S_dax__adag_3:
      case S_dax__adag_4:
      case S_dax__adag:
      case S_dax__adag_5:
        SET(S_dax__adag_5);
        break;
    }
  }
  YY_BREAK
case 103:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of child element.", yytext[0]);
YY_BREAK
case 104:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `child' element start tag.", yytext);
YY_BREAK
case YY_STATE_EOF(AL_dax__child):
  FAIL("EOF in attribute list of `child' element.");
  YY_BREAK

case 105:
/* rule 105 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__child();
  popbuffer(); /* attribute */
  switch (YY_START) {
    case S_dax__adag_1:
    case S_dax__adag_3:
    case S_dax__adag_4:
    case S_dax__adag:
    case S_dax__adag_5:
      SET(S_dax__adag_5);
      break;
  }
}
        YY_BREAK
case 106:
/* rule 106 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</child>' expected.", yytext);
YY_BREAK
case 107:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</child>' expected.", yytext[0]);
YY_BREAK
case YY_STATE_EOF(S_dax__child_2):
case YY_STATE_EOF(S_dax__child):
case YY_STATE_EOF(E_dax__child):
  FAIL("Premature EOF: `</child>' expected.");
  YY_BREAK

case 108:
/* rule 108 can match eol */
YY_RULE_SETUP
FAIL("Starting tag <parent> is not allowed here.");
YY_BREAK
case 109:
/* rule 109 can match eol */
YY_RULE_SETUP
{
  AX_dax__parent_ref    = 0;
  dax__parent_ref_isset = 0;
  ENTER(AL_dax__parent);
  pushbuffer(0);
}
        YY_BREAK

case 110:
/* rule 110 can match eol */
YY_RULE_SETUP
if (dax__parent_ref_isset != 0) {
  FAIL("Multiple definition of attribute ref in <dax__parent>");
}
dax__parent_ref_isset = 1;
ENTER(VALUE1);
BUFFERSET(AX_dax__parent_ref);
YY_BREAK
case 111:
/* rule 111 can match eol */
YY_RULE_SETUP
if (dax__parent_ref_isset != 0) {
  FAIL("Multiple definition of attribute ref in <dax__parent>");
}
dax__parent_ref_isset = 1;
ENTER(VALUE2);
BUFFERSET(AX_dax__parent_ref);
YY_BREAK
case 112:
YY_RULE_SETUP
{
  if (!AX_dax__parent_ref)
    FAIL("Required attribute `ref' not set for `parent' element.");
  LEAVE;
  STag_dax__parent();
  dax__pcdata_ix = 0;
  ENTER(E_dax__parent);
 }
	YY_BREAK
case 113:
YY_RULE_SETUP
{
  if (!AX_dax__parent_ref)
    FAIL("Required attribute `ref' not set for `parent' element.");
  LEAVE;
  STag_dax__parent();
  dax__pcdata_ix = 0;
  ETag_dax__parent();
  popbuffer(); /* attribute */
  switch (YY_START) {
    case S_dax__child:
    case S_dax__child_1:
    case S_dax__child_2:
      SET(S_dax__child_2);
      break;
  }
 }
	YY_BREAK
case 114:
YY_RULE_SETUP
FAIL("Unexpected character `%c' in attribute list of parent element.", yytext[0]);
YY_BREAK
case 115:
YY_RULE_SETUP
FAIL("Bad attribute `%s' in `parent' element start tag.", yytext);
YY_BREAK
case YY_STATE_EOF(AL_dax__parent):
  FAIL("EOF in attribute list of `parent' element.");
  YY_BREAK

case 116:
/* rule 116 can match eol */
YY_RULE_SETUP
{
  LEAVE;
  ETag_dax__parent();
  popbuffer(); /* attribute */
  switch (YY_START) {
    case S_dax__child:
    case S_dax__child_1:
    case S_dax__child_2:
      SET(S_dax__child_2);
      break;
  }
 }
	YY_BREAK
case 117:
/* rule 117 can match eol */
YY_RULE_SETUP
FAIL("Unexpected end-tag `%s': `</parent>' expected.", yytext);
YY_BREAK
case 118:
YY_RULE_SETUP
FAIL("Unexpected character `%c': `</parent>' expected.", yytext[0]);
YY_BREAK
case YY_STATE_EOF(E_dax__parent):
  FAIL("Premature EOF: `</parent>' expected.");
  YY_BREAK

  /* EPILOG: after the root element. */

case 119:
YY_RULE_SETUP
{SET(PROLOG); yyless(0); CLEANUP; return -1;}
	YY_BREAK
case YY_STATE_EOF(EPILOG):
SUCCEED;
	YY_BREAK

/* CHARACTER DATA. */

/* Non-defined standard entities... */
case 120:
YY_RULE_SETUP
BUFFERPUTC('&');
	YY_BREAK
case 121:
YY_RULE_SETUP
BUFFERPUTC('<');
	YY_BREAK
case 122:
YY_RULE_SETUP
BUFFERPUTC('>');
	YY_BREAK
case 123:
YY_RULE_SETUP
BUFFERPUTC('\'');
	YY_BREAK
case 124:
YY_RULE_SETUP
BUFFERPUTC('"');
	YY_BREAK
/* Character entities. */
case 125:
YY_RULE_SETUP
BUFFERPUTC((unsigned char)atoi(yytext+2));
	YY_BREAK
case 126:
YY_RULE_SETUP
BUFFERPUTC((unsigned char)strtol(yytext+3,NULL,16));
	YY_BREAK

case 127:
/* rule 127 can match eol */
case 128:
/* rule 128 can match eol */
case 129:
/* rule 129 can match eol */
case 130:
/* rule 130 can match eol */
YY_RULE_SETUP
BUFFERPUTC('\n');
	YY_BREAK

case 131:
YY_RULE_SETUP
ENTER(CDATA);
	YY_BREAK
case 132:
YY_RULE_SETUP
FAIL("Unexpected `]""]>' in character data.");
	YY_BREAK

case 133:
YY_RULE_SETUP
BUFFERDONE; LEAVE;
	YY_BREAK
case YY_STATE_EOF(VALUE1):
FAIL("EOF in literal (\"'\" expected).");
	YY_BREAK

case 134:
YY_RULE_SETUP
BUFFERDONE; LEAVE;
	YY_BREAK
case YY_STATE_EOF(VALUE2):
FAIL("EOF in literal (`\"' expected).");
	YY_BREAK

case 135:
/* rule 135 can match eol */
YY_RULE_SETUP
BUFFERPUTC(yytext[0]);
	YY_BREAK
case 136:
YY_RULE_SETUP
FAIL("Spurious `%c' in character data.",yytext[0]);
	YY_BREAK

case 137:
YY_RULE_SETUP
LEAVE;
	YY_BREAK
/* "]""]"		BUFFERPUTC(yytext[0]); BUFFERPUTC(yytext[1]); */
case 138:
YY_RULE_SETUP
BUFFERPUTC(yytext[0]);
	YY_BREAK
case YY_STATE_EOF(CDATA):
FAIL("EOF in CDATA section.");
	YY_BREAK

/* Impossible rules to avoid warnings from flex(1). */
/* Ideally, this should be replaced by code in flexml.pl that
    generates just the states not covered by other rules. */

case 139:
/* rule 139 can match eol */
YY_RULE_SETUP
FAIL("Syntax error on character `%c'.", yytext[0]);
	YY_BREAK

case 140:
YY_RULE_SETUP
ECHO;
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(ROOT_dax__adag):
case YY_STATE_EOF(S_dax__adag_2):
case YY_STATE_EOF(S_dax__adag_4):
case YY_STATE_EOF(S_dax__job_1):
case YY_STATE_EOF(S_dax__child_1):
case YY_STATE_EOF(IMPOSSIBLE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 775 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 775 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 774);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_size_t) (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) yyalloc( new_size  );

		else
			(yy_start_stack) = (int *) yyrealloc(
					(void *) (yy_start_stack), new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        yyfree( (yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

/* Element context stack lookup. */
int dax__element_context(int i)
{
  return (0<i && i<yy_start_stack_depth
	  ? yy_start_stack[yy_start_stack_ptr - i]
	  : 0);
}

#ifdef FLEX_DEBUG
void print_yy_stack(char* fmt, ...)
{
  int i = 0; va_list ap; va_start(ap, fmt);
  vfprintf(stderr, fmt, ap);
  if (dax__statenames) {
      for (i=1; i<yy_start_stack_ptr; i++) {
          fprintf(stderr, "%s/", dax__statenames[yy_start_stack[i] ]);
      }
      fprintf(stderr,"%s\n", dax__statenames[YY_START]);
  }
  va_end(ap);
}

void print_dax__bufferstack()
{
    int i;
    fputs("Buffer: ", stderr);
    for (i = 0; i < blimit; i++) {
       if ( dax__bufferstack[i] == '\377' ) break;
         putc(dax__bufferstack[i], stderr);
    }
    putc('\n', stderr);
}

static void debug_enter(int state, const char* statename) {
  yy_push_state(state);
  if (yy_flex_debug) {
       print_yy_stack("--ENTER(%s) : ",statename);
       print_dax__bufferstack();
  }
}

static void debug_leave(void) {
    if (yy_flex_debug) {
        print_yy_stack("--LEAVE : ");
	print_dax__bufferstack();
    }
  yy_pop_state();
}

static void debug_set(int state, const char* statename) {
  BEGIN(state);
  if (yy_flex_debug) print_yy_stack("--SET(%s) : ",statename);
}
#endif

static void cleanup(void)
{
    if (dax__statenames) {
        free(dax__statenames);
	dax__statenames = NULL;
    }
    free(dax__bufferstack);
    dax__bufferstack = NULL;

    free(indexstack);
    indexstack = NULL;
}

static int fail(const char* fmt, ...)
{
    int chars_left, used;
    va_list ap; va_start(ap, fmt);
#ifdef FLEXML_yylineno
    used = sprintf(flexml_err_msg, "Invalid XML (XML input line %d, state %d): ", yylineno, YY_START);
#else
    used  = sprintf(flexml_err_msg, "Invalid XML (state %d): ", YY_START);
#endif
    chars_left = flexml_max_err_msg_size - used - 1;
    vsnprintf(flexml_err_msg + used, chars_left, fmt, ap);
    va_end(ap);

#ifndef FLEXML_quiet_parser
    /* print directly to sdterr */
    fprintf(stderr, "%s\n", flexml_err_msg);
    flexml_err_msg[0] = '\0';
#endif

    cleanup();

    return 1;
}

